@@ -27,7 +27,8 @@ Implementation Notes
 
 **With Native Networking**
 
-* CircuitPython's Wifi Module: https://docs.circuitpython.org/en/latest/shared-bindings/wifi/index.html
+* CircuitPython's Wifi Module:
+    https://docs.circuitpython.org/en/latest/shared-bindings/wifi/index.html
 * Adafruit's Requests Library: https://github.com/adafruit/Adafruit_CircuitPython_Requests/
 """
 
@@ -36,7 +37,7 @@ from .iot_mqtt import IoTResponse
 from .iotcentral_device import IoTCentralDevice
 from .iothub_device import IoTHubDevice
 
-__version__ = "2.5.11"
+__version__ = "2.5.13"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AzureIoT.git"
 
 __all__ = ["IoTHubDevice", "IoTCentralDevice", "IoTResponse", "IoTError"]
